@@ -6,6 +6,7 @@ from django.conf import settings
 from django.db import models, DatabaseError, transaction
 from django.utils.translation import ugettext_lazy as _
 from django.utils import six
+from django.core.cache import cache
 
 from decimal import Decimal
 import datetime
@@ -13,6 +14,12 @@ import datetime
 from .utils import default
 from .widgets import JSONWidget
 from .forms import JSONFormField
+from jsonfield import __version__
+
+DB_TYPE_CACHE_KEY = (
+    'django-jsonfield:db-type:%s' % __version__ +
+    '%(ENGINE)s:%(HOST)s:%(PORT)s:%(NAME)s'
+)
 
 class JSONField(six.with_metaclass(models.SubfieldBase, models.Field)):
     """
@@ -27,7 +34,7 @@ class JSONField(six.with_metaclass(models.SubfieldBase, models.Field)):
         if not kwargs.get('null', False):
             kwargs['default'] = kwargs.get('default', dict)
         self.encoder_kwargs = {
-            'indent': kwargs.get('indent', getattr(settings, 'JSONFIELD_INDENT', None))
+            'indent': kwargs.pop('indent', getattr(settings, 'JSONFIELD_INDENT', None))
         }
         super(JSONField, self).__init__(*args, **kwargs)
         self.validate(self.get_default(), None)
@@ -62,17 +69,23 @@ class JSONField(six.with_metaclass(models.SubfieldBase, models.Field)):
         return 'TextField'
     
     def db_type(self, connection):
-        # Test to see if we support JSON querying.
-        # (Protip: nothing does, at this stage).
-        cursor = connection.cursor()
-        try:
-            sid = transaction.savepoint(using=connection.alias)
-            cursor.execute('SELECT \'{}\'::json = \'{}\'::json;')
-        except DatabaseError:
-            transaction.savepoint_rollback(sid, using=connection.alias)
-            return 'text'
-        else:
-            return 'json'
+        cache_key = DB_TYPE_CACHE_KEY % connection.settings_dict
+        db_type = cache.get(cache_key)
+        
+        if not db_type:
+            # Test to see if we support JSON querying.
+            cursor = connection.cursor()
+            try:
+                sid = transaction.savepoint(using=connection.alias)
+                cursor.execute('SELECT \'{}\'::json = \'{}\'::json;')
+            except DatabaseError:
+                transaction.savepoint_rollback(sid, using=connection.alias)
+                db_type = 'text'
+            else:
+                db_type = 'json'
+            cache.set(cache_key, db_type)
+        
+        return db_type
     
     def to_python(self, value):
         if isinstance(value, six.string_types):
